function [x, lambda, stats] = napheap (y, d, a, blo, bhi, lo, hi, parm, la) %#ok
%NAPHEAP solve a separable convex quadratic knapsack problem
%
% [x, lambda, stats] = napheap (y, d, a, blo, bhi, lo, hi, parm, lambda_guess)
%
% Solve a separable convex quadratic knapsack problem of the form:
%
%   min .5*x'*D*x - y'*x  subject to  lo <= x <= hi, blo <= a'*x <= bhi.
%
% where y, d, a, lo, hi are vectors of length n, blo and bhi are scalars,
% and D=diag(d) is a diagonal matrix with a nonnegative diagonal.  If not
% present or empty, lower/upper bounds default to 0 and inf, respectively,
% and a and d default to ones(n,1).  lambda_guess is an optional initial
% guess for the Lagrange multiplier, lambda.
%
% Type 'napheap' with no inputs or outputs for more details on the algorithm,
% for how to use the parms input struct set non-default parameters, and for
% a description of lambda and the stats output struct.
%
% Example:
%
%   % create a simple knapsack problem and solve it with napheap
%   n = 20 ;
%   d = 5 + 5*rand (n, 1) ;
%   a = 20*rand (n, 1) - 10 ;
%   y = 20*rand (n, 1) - 10 ;
%   lo = -ones (n, 1) ;
%   hi =  ones (n, 1) ;
%   cumlo = 0 ;
%   cumhi = 0 ;
%   for j = 1:n
%       t = a (j)*lo (j) ;
%       s = a (j)*hi (j) ;
%       cumlo = cumlo + min (t, s) ;
%       cumhi = cumhi + max (t, s) ;
%   end
%   blo = cumlo + (cumhi-cumlo)*rand ;
%   bhi = blo + 10 ;
%   [x lambda] = napheap (y, d, a, blo, bhi, lo, hi) ;
%   err = napheap_check (x, lambda, y, d, a, blo, bhi, lo, hi)
%
% See also NAPHEAP_CHECK, NAPHEAP_INSTALL, NAPHEAP_TEST.

% Copyright 2013, T. A. Davis, W. W. Hager, and J. T. Hungerford
% http://www.suitesparse.com
% For a tech report, see Doc/napheap.pdf in this distribution.

error ('napheap mexFunction not found') ;
